@@ -7,11 +7,11 @@ import numpy as np
 
 from one.api import ONE
 from ibllib.pipes import tasks
-from ibllib.misc import version
 from one.alf.exceptions import ALFObjectNotFound
+from neuropixel import trace_header, TIP_SIZE_UM
 
+from ibllib import __version__ as ibllib_version
 from ibllib.pipes.ephys_alignment import EphysAlignment
-from ibllib.ephys.neuropixel import trace_header, TIP_SIZE_UM
 from ibllib.pipes.histology import interpolate_along_track
 from ibllib.atlas import AllenAtlas
 
@@ -36,7 +36,7 @@ class ReportSnapshot(tasks.Task):
         jsons = []
         texts = []
         for f in self.outputs:
-            json_dict = dict(tag=report_tag, version=version.ibllib(),
+            json_dict = dict(tag=report_tag, version=ibllib_version,
                              function=(function or str(self.__class__).split("'")[1]), name=f.stem)
             if extra_dict is not None:
                 assert isinstance(extra_dict, dict)
